EmbedAttributeBuilder class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
horizontalRule → NotusAttribute<Map<String, dynamic>?>
no setter
key → String
Unique key of this attribute.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → NotusAttributeScope
finalinherited
unset → NotusAttribute<Map<String, dynamic>?>
no setteroverride

Methods

image(String source) → NotusAttribute<Map<String, dynamic>?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withValue(Map<String, dynamic>? value) → NotusAttribute<Map<String, dynamic>?>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited