LinkAttributeBuilder class

Builder for link attribute values.

There is no need to use this class directly, consider using NotusAttribute.link instead.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
Unique key of this attribute.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → NotusAttributeScope
finalinherited
unset → NotusAttribute<String?>
no setterinherited

Methods

fromString(String value) → NotusAttribute<String>
Creates a link attribute with specified link value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withValue(String value) → NotusAttribute<String>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited