NotusAttributeBuilder<T> class abstract

Builder for style attributes.

Useful in scenarios when an attribute value is not known upfront, for instance, link attribute.

See also:

Implemented types
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
Unique key of this attribute.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → NotusAttributeScope
final
unset → NotusAttribute<T?>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
withValue(T value) → NotusAttribute<T>

Operators

operator ==(Object other) → bool
The equality operator.
inherited